*********************
Dark Field Correction
*********************

If you loaded a set of Dark Field (DF) images, you probably want to correct all your
images (sample and OB) for dark field correction

>>> o_norm.df_correction()

In case you did not loaded a set of DF, this correction will leave the images untouched
